@@ -255,11 +255,6 @@ class KitsuTrackingManager(tracking.TrackingManager, object):
             LOGGER.warning('Impossible to retrieve assets because user is not logged into Kitsu!')
             return
 
-        assets_path = artellapipe.AssetsMgr().get_assets_path()
-        if not artellapipe.AssetsMgr().is_valid_assets_path():
-            LOGGER.warning('Impossible to retrieve assets from invalid assets path: "{}"'.format(assets_path))
-            return
-
         project_id = kitsu_lib.config.get('project_id', default=None)
         if not project_id:
             LOGGER.warning('Impossible to retrieve assets because does not defines a valid Kitsu ID')
@@ -293,12 +288,6 @@ class KitsuTrackingManager(tracking.TrackingManager, object):
             LOGGER.warning('Impossible to retrieve sequences because user is not logged into Kitsu!')
             return
 
-        production_path = self._project.get_production_path()
-        if not production_path or not os.path.isdir(production_path):
-            LOGGER.warning(
-                'Impossible to retrieve sequences from invalid production path: "{}"'.format(production_path))
-            return
-
         project_id = kitsu_lib.config.get('project_id', default=None)
         if not project_id:
             LOGGER.warning('Impossible to retrieve assets because does not defines a valid Kitsu ID')
@@ -336,12 +325,6 @@ class KitsuTrackingManager(tracking.TrackingManager, object):
             LOGGER.warning('Impossible to retrieve sequences because user is not logged into Kitsu!')
             return
 
-        production_path = self._project.get_production_path()
-        if not production_path or not os.path.isdir(production_path):
-            LOGGER.warning(
-                'Impossible to retrieve sequences from invalid production path: "{}"'.format(production_path))
-            return
-
         project_id = kitsu_lib.config.get('project_id', default=None)
         if not project_id:
             LOGGER.warning('Impossible to retrieve assets because does not defines a valid Kitsu ID')
@@ -478,6 +461,15 @@ class KitsuTrackingManager(tracking.TrackingManager, object):
 
         return ''
 
+    def get_task_by_id(self, task_id):
+        """
+        Returns task with the given ID
+        :param task_id: str
+        :return:
+        """
+
+        return kitsulib.get_task(task_id=task_id)
+
     def get_tasks_in_shot(self, shot_id):
         """
         Returns all tasks in given shot
@@ -490,12 +482,13 @@ class KitsuTrackingManager(tracking.TrackingManager, object):
 
         return kitsulib.get_all_tasks_for_shot(shot_id=shot_id)
 
-    def upload_shot_task_preview(self, task_id, preview_file_path, comment=''):
+    def upload_shot_task_preview(self, task_id, preview_file_path, comment='', status=None):
         """
         Uploads task preview file to the tracker server
         :param task_id: str, ID of task to submit preview file into
         :param preview_file_path: str, file path of the preview file to upload
         :param comment: str, comment to link to the task with given preview
+        :param status: str, comment to link to the task with given preview
         :return: bool
         """
 
@@ -506,7 +499,7 @@ class KitsuTrackingManager(tracking.TrackingManager, object):
             LOGGER.warning('Given preview file "{}" does not exists!'.format(preview_file_path))
             return False
 
-        return kitsulib.upload_shot_task_preview(task_id, preview_file_path, comment)
+        return kitsulib.upload_shot_task_preview(task_id, preview_file_path, comment, status=status)
 
     def all_task_types(self):
         """
@@ -516,6 +509,14 @@ class KitsuTrackingManager(tracking.TrackingManager, object):
 
         return kitsulib.get_all_task_types()
 
+    def all_task_statuses(self):
+        """
+        Returns all task statuses for current project
+        :return:
+        """
+
+        return kitsulib.get_all_task_statuses()
+
     def all_task_types_for_assets(self):
         """
         Returns all task types for assets
@@ -546,6 +547,15 @@ class KitsuTrackingManager(tracking.TrackingManager, object):
 
         return shot_task_types
 
+    def get_task_status(self, task_id):
+        """
+        Returns the status of the given task name
+        :param task_id: str
+        :return:
+        """
+
+        return kitsulib.get_task_status(task_id)
+
     def _load_user_settings(self):
         """
         Internal function that tries to retrieve user data from project settings
